@@ -1,6 +1,9 @@
 import os
 import re
 import pandas as pd
+import yaml
+import textwrap
+
 from mkdocs.plugins import BasePlugin
 from mkdocs.config import config_options
 from mkdocs.exceptions import ConfigurationError
@@ -28,11 +31,19 @@ def read_excel(*args, **kwargs):
     return df.to_markdown(index=False, tablefmt="pipe")
 
 
+def read_yaml(*args, **kwargs):
+    with open(args[0], "r") as f:
+        df = pd.json_normalize(yaml.safe_load(f), **kwargs)
+
+    return df.to_markdown(index=False, tablefmt="pipe")
+
+
 READERS = {
     "read_csv": read_csv,
     "read_table": read_table,
     "read_fwf": read_fwf,
     "read_excel": read_excel,
+    "read_yaml": read_yaml,
 }
 
 
@@ -99,18 +110,21 @@ class TableReaderPlugin(BasePlugin):
         mkdocs_dir = os.path.dirname(os.path.abspath(config["config_file_path"]))
 
         for reader, function in READERS.items():
-
+            
             # Regex pattern for tags like {{ read_csv(..) }}
-            # with a match group to extract the arguments (positional and keywords)
+            # match group 0: to extract any leading whitespace 
+            # match group 1: to extract the arguments (positional and keywords)
             tag_pattern = re.compile(
-                "\{\{ %s\((.+)\) \}\}" % reader, flags=re.IGNORECASE
+                "( *)\{\{ %s\((.+)\) \}\}" % reader, flags=re.IGNORECASE
             )
 
             matches = re.findall(tag_pattern, markdown)
+            
+            
             for result in matches:
 
                 # Safely parse the arguments
-                pd_args, pd_kwargs = parse_argkwarg(result)
+                pd_args, pd_kwargs = parse_argkwarg(result[1])
 
                 # Make sure the path is relative to "data_path"
                 if len(pd_args) > 0:
@@ -122,8 +136,7 @@ class TableReaderPlugin(BasePlugin):
                     file_path = os.path.join(self.config.get("data_path"), file_path)
                     pd_kwargs["filepath_or_buffer"] = file_path
 
-                # Insert markdown table
-                # By replacing first occurance of the regex pattern
+                # Load the table
                 with cd(mkdocs_dir):
                     if not os.path.exists(file_path):
                         raise FileNotFoundError(
@@ -132,6 +145,21 @@ class TableReaderPlugin(BasePlugin):
 
                     markdown_table = function(*pd_args, **pd_kwargs)
 
+                # Deal with indentation
+                # f.e. relevant when used inside content tabs
+                leading_spaces = result[0]
+                # make sure it's in multiples of 4 spaces
+                leading_spaces = int(len(leading_spaces) / 4) * "    "
+                # indent entire table
+                fixed_lines = []
+                for line in markdown_table.split('\n'):
+                    fixed_lines.append(textwrap.indent(line, leading_spaces))
+                
+                markdown_table = "\n".join(fixed_lines)
+
+                # Insert markdown table
+                # By replacing first occurance of the regex pattern
                 markdown = tag_pattern.sub(markdown_table, markdown, count=1)
 
+
         return markdown
